@@ -13,61 +13,21 @@ Description:
 
 """
 
-from os import makedirs
-from pathlib import Path
 from time import time
 
-from inspyre_toolbox.live_timer.errors import TimerNotStartedError
+from inspyre_toolbox.live_timer.errors import TimerNotStartedError, TimerNotRunningError
+from inspyre_toolbox.live_timer.history import TimerHistory
+
+from inspyre_toolbox.core_helpers.logging import add_isl_child, ROOT_LOGGER, ROOT_ISL_DEVICE, PROG_LOGGERS
 
 
-class TimerHistory(object):
+LOG_NAME = 'InspyreToolbox.live_timer'
 
-    def __init__(self, elapsed_method):
-        self.get_elapsed = elapsed_method
-        self.ledger = []
-        self.actions = [
-                "START",
-                "STOP",
-                "PAUSE",
-                "UNPAUSE",
-                "RESET",
-                "CREATE",
-                "QUERY"
-                ]
-        self.add("CREATE")
+LOG = add_isl_child(LOG_NAME)
 
-    def add(self, action: str = "START"):
-        action = action.upper()
-        entry = {
-            "time": time(),
-            "elapsed_since_last": "",
-            "action": action,
-            "rt_at_create": ""
-        }
-        if action == "CREATE":
-            entry['elapsed_since_last'] = 0.00
-        else:
-            entry['elapsed_since_last'] = self.get_elapsed(self.ledger[-1]['time'])
-            entry['rt_at_create'] = self.get_elapsed(self.ledger[0]['time'])
+ROOT_ISL_DEVICE.adjust_level('debug')
 
-        self.ledger.append(entry)
-
-    def write(self):
-        data_path = Path("~/Inspyre-Softworks/Inspyre-Toolbox/data").expanduser()
-
-        filename = f'ledger_{str(time()).split(".")[0]}'
-        filepath = str(f'{str(data_path)}/{filename}.txt')
-
-        filepath = str(Path(filepath).resolve())
-
-        if not data_path.exists():
-            makedirs(data_path)
-
-        with open(filepath, "w") as fp:
-            fp.write(str(self.ledger))
-
-    def reset(self):
-        self.ledger = []
+LOG.debug('Log started!')
 
 
 def format_seconds_to_hhmmss(seconds):
@@ -79,7 +39,6 @@ def format_seconds_to_hhmmss(seconds):
 
 
 class Timer(object):
-    
     def __repr__(self):
         statement = "Timer("\
                     f"Started: {self.started} |"
@@ -88,22 +47,32 @@ class Timer(object):
             runtime = format_seconds_to_hhmmss(runtime)
             statement += f" Started: {self.start_time} - Current Runtime: {runtime}"
 
-    def __init__(self):
+    def __init__(self, auto_start=False):
+        
+        self.log_name = LOG_NAME + '.Timer'
+        
+        # Set up logger
+        self.log = add_isl_child(self.log_name)
         
         # Define some default attribute values
         
-        self.start_time = None
-        self.is_running = False
-        self.pause_start = time()
-        self.pause_end = None
+        self.running       = False
+        self.mark_2           = None
+        self.pause_end        = None
+        self.pause_start      = time()
+        self.paused           = False
+        self.start_time       = None
+        self.started          = False
+        self.stopped          = False
         self.total_pause_time = 0
-        self.started = False
-        self.paused = False
-        self.was_paused = False
-        self.mark_2 = None
+        self.was_paused       = False
+        
+        self.log.debug('Set up class attributes.')
 
         # Start a Timer history object to track times for resets
         self.history = TimerHistory(self.__get_elapsed)
+        
+        self.log.debug('Timer class instantiated!')
 
     def __get_elapsed(self, ts=None, sans_pause: bool = False, seconds=False):
         """
@@ -116,13 +85,22 @@ class Timer(object):
         Returns:
 
         """
+        log = add_isl_child(self.log_name + '__get_elapsed')
+        
+        
         diff_time = self.start_time if ts is None else ts
-        self.mark_2 = time()
-        # print(self.mark_2)
-        # print(self.start_time)
-
+        
+        
+        
+        
+        # ver1.2.7
+        # If we were running but are now stopped, we will skip marking
+        if not self.stopped:
+            self.mark_2 = time()
+        
+        
         diff = self.mark_2 - diff_time
-        # print(format_seconds_to_hhmmss(diff))
+        
         if sans_pause:
             return format_seconds_to_hhmmss(diff)
 
@@ -137,14 +115,18 @@ class Timer(object):
         return diff if seconds else format_seconds_to_hhmmss(diff)
 
     def get_elapsed(self, *args, **kwargs):
-        if self.is_running:
+        if self.running:
             self.history.add("QUERY")
             return self.__get_elapsed(*args, **kwargs)
         else:
-            try:
-                raise TimerNotStartedError(skip_print=True)
-            except TimerNotStartedError as e:
-                print(e.message)
+            if self.stopped:
+                self.history.add("QUERY")
+                return self.__get_elapsed(*args, **kwargs)
+            else:
+                try:
+                    raise TimerNotStartedError(skip_print=True)
+                except TimerNotStartedError as e:
+                    print(e.message)
 
     def reset(self):
         """
@@ -153,13 +135,15 @@ class Timer(object):
 
         """
         self.history.add(action="RESET")
-        self.was_paused = False
-        self.paused = False
-        self.total_pause_time = 0
-        self.pause_start = None
-        self.pause_end = None
-        self.started = False
-        self.mark_2 = None
+        
+        return Timer()
+        
+        # if self.running:
+        #     self.stop()
+        # self.total_pause_time = 0
+        # self.pause_start = None
+        # self.pause_end = None
+        # self.started = False
         
     def restart(self):
         self.reset()
@@ -175,7 +159,7 @@ class Timer(object):
         self.start_time = time()
         self.started = True
         self.history.add()
-        self.is_running = True
+        self.running = True
 
     def pause(self):
         """
@@ -190,6 +174,10 @@ class Timer(object):
 
         :return:
         """
+        if not self.started:
+            raise TimerNotStartedError()
+        if not self.running:
+            raise TimerNotRunningError()
         if self.paused:
             return False
         self.pause_start = time()
@@ -199,7 +187,7 @@ class Timer(object):
 
     def unpause(self):
         """
-
+tim
         Un-Pause the running timer.
 
         This function will unpause the running timer. What that really means in this context is that since it marks the
@@ -212,6 +200,10 @@ class Timer(object):
         :return:
               bool
         """
+        if not self.started:
+            raise TimerNotStartedError()
+        if not self.running:
+            raise TimerNotRunningError()
         if self.paused:
             self.pause_end = time()
             diff = self.pause_end - self.pause_start
@@ -220,3 +212,15 @@ class Timer(object):
             self.history.add("UNPAUSE")
         else:
             return False
+
+    def stop(self):
+        if not self.started:
+            raise TimerNotStartedError()
+        if self.running:
+            self.running = False
+            self.paused = False
+            self.stopped = True
+            self.mark_2 = time()
+        else:
+            raise TimerNotRunningError()
+
