@@ -20,7 +20,7 @@ print(__ver_parser.sections())
 class Version(object):
 
     def _check_most_current(self):
-        res = up_to_date('inspy_logger')
+        res = up_to_date('inspyre_toolbox')
 
         self.is_latest = res
 
@@ -35,7 +35,7 @@ class Version(object):
         if self.pre_release:
             self.pr_info = version_info['PRE-RELEASE']
             self.pr_type = self.pr_info['type']
-            self.pr_num = self.pr_info['build_no']
+            self.pr_num = self.pr_info['build-no']
             if self.pr_type.lower() == 'alpha':
                 prt_tag = 'a'
             elif self.pr_type.lower() == 'beta':
